@@ -5,6 +5,7 @@ from pathlib import Path
 
 from notion.client import NotionClient
 
+from enex2notion.cli_wkhtmltopdf import ensure_wkhtmltopdf
 from enex2notion.enex_parser import iter_notes
 from enex2notion.enex_uploader import get_import_root, upload_note
 from enex2notion.enex_uploader_modes import get_notebook_database, get_notebook_page
@@ -35,9 +36,17 @@ class DoneFile(object):
 
 
 class EnexUploader(object):
-    def __init__(self, import_root, mode: str, done_file, add_meta: bool):
+    def __init__(
+        self,
+        import_root,
+        mode: str,
+        mode_webclips: str,
+        done_file: Path,
+        add_meta: bool,
+    ):
         self.import_root = import_root
         self.mode = mode
+        self.mode_webclips = mode_webclips
         self.done_hashes = DoneFile(done_file) if done_file else set()
         self.add_meta = add_meta
 
@@ -51,11 +60,9 @@ class EnexUploader(object):
                 logger.debug(f"Skipping note '{note.title}' (already uploaded)")
                 continue
 
-            if note.is_webclip:
-                logger.warning(f"Skipping note '{note.title}' [WEBCLIPS NOT SUPPORTED]")
-                continue
-
-            note_blocks = parse_note(note, self.add_meta)
+            note_blocks = parse_note(
+                note, mode_webclips=self.mode_webclips, is_add_meta=self.add_meta
+            )
             if not note_blocks:
                 continue
 
@@ -78,6 +85,9 @@ def cli(argv):
 
     _setup_logging(args.verbose)
 
+    if args.mode_webclips == "PDF":
+        ensure_wkhtmltopdf()
+
     if args.token:
         root = get_import_root(
             NotionClient(token_v2=args.token), "Evernote ENEX Import"
@@ -88,9 +98,15 @@ def cli(argv):
         )
         root = None
 
-    enex_uploader = EnexUploader(root, args.mode, args.done_file, args.add_meta)
+    enex_uploader = EnexUploader(
+        import_root=root,
+        mode=args.mode,
+        mode_webclips=args.mode_webclips,
+        done_file=args.done_file,
+        add_meta=args.add_meta,
+    )
 
-    for enex_input in map(Path, args.enex_input):
+    for enex_input in args.enex_input:
         if enex_input.is_dir():
             logger.info(f"Processing directory '{enex_input.name}'...")
             for enex_file in sorted(enex_input.glob("**/*.enex")):
@@ -133,6 +149,14 @@ def parse_args(argv):
                 " (default: DB)"
             ),
         },
+        "--mode-webclips": {
+            "choices": ["TXT", "PDF"],
+            "default": "TXT",
+            "help": (
+                "convert web clips to text (TXT) or pdf (PDF) before upload"
+                " (default: TXT)"
+            ),
+        },
         "--add-meta": {
             "action": "store_true",
             "default": False,
@@ -142,7 +166,7 @@ def parse_args(argv):
             ),
         },
         "--done-file": {
-            "type": str,
+            "type": Path,
             "metavar": "FILE",
             "help": "file for uploaded notes hashes to resume interrupted upload",
         },
@@ -164,8 +188,10 @@ def parse_args(argv):
 
 
 def _setup_logging(is_verbose):
-    if is_verbose:
-        logging.basicConfig(level=logging.DEBUG, format="%(levelname)s: %(message)s")
-    else:
-        logging.basicConfig(level=logging.INFO, format="%(levelname)s: %(message)s")
+    logging.basicConfig(format="%(levelname)s: %(message)s")
+
+    logging.getLogger("enex2notion").setLevel(
+        logging.DEBUG if is_verbose else logging.INFO
+    )
+
     logging.getLogger("urllib3").setLevel(logging.ERROR)
